
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.40'
version = '1.1.40'
full_version = '1.1.40'
git_revision = 'bc0a4f30d7708048f8a4d65312b777ca3a5f73ac'
release = True

if not release:
    version = full_version
    short_version += ".dev"
